@@ -7,7 +7,7 @@ from starlette.requests import Request
 from starlette.responses import Response
 from starlette.types import ASGIApp
 
-from core import log_request
+from api_analytics.core import log_request
 
 
 class Analytics(BaseHTTPMiddleware):
